@@ -20,7 +20,7 @@ limitations under the License.
 """
 
 # Module version
-__version_info__ = (0, 1, 9)
+__version_info__ = (0, 2, 0)
 __version__ = ".".join(str(x) for x in __version_info__)
 
 # Documentation strings format
@@ -32,6 +32,7 @@ import sys
 
 # ------------------------------------------------------------------------------
 
+
 class LocalClasses(dict):
     """
     Associates local classes with their names (used in the jsonclass module)
@@ -46,6 +47,7 @@ class LocalClasses(dict):
 
 # ------------------------------------------------------------------------------
 
+
 class Config(object):
     """
     This is pretty much used exclusively for the 'jsonclass'
@@ -89,9 +91,9 @@ class Config(object):
 
         # Default user agent
         if user_agent is None:
-            user_agent = 'jsonrpclib/{0} (Python {1})' \
-                 .format(__version__,
-                         '.'.join(str(ver) for ver in sys.version_info[0:3]))
+            user_agent = 'jsonrpclib/{0} (Python {1})'.format(
+                __version__, '.'.join(str(ver)
+                                      for ver in sys.version_info[0:3]))
         self.user_agent = user_agent
 
         # The list of classes to use for jsonclass translation.
