@@ -52,7 +52,7 @@ See https://github.com/tcalmant/jsonrpclib for more info.
 """
 
 # Module version
-__version_info__ = (0, 1, 9)
+__version_info__ = (0, 2, 0)
 __version__ = ".".join(str(x) for x in __version_info__)
 
 # Documentation strings format
@@ -71,6 +71,7 @@ import uuid
 
 try:
     # Python 3
+    # pylint: disable=F0401,E0611
     from urllib.parse import splittype
     from urllib.parse import splithost
     from xmlrpc.client import Transport as XMLTransport
@@ -80,6 +81,7 @@ try:
 
 except ImportError:
     # Python 2
+    # pylint: disable=F0401,E0611
     from urllib import splittype
     from urllib import splithost
     from xmlrpclib import Transport as XMLTransport
@@ -94,6 +96,7 @@ except ImportError:
 from jsonrpclib import jsonclass
 
 try:
+    # pylint: disable=F0401,E0611
     # Using cjson
     import cjson
 
@@ -105,6 +108,7 @@ try:
         return cjson.decode(json_string)
 
 except ImportError:
+    # pylint: disable=F0401,E0611
     # Use json or simplejson
     try:
         import json
@@ -112,7 +116,7 @@ except ImportError:
         try:
             import simplejson as json
         except ImportError:
-            raise ImportError('You must have the cjson, json, or simplejson ' \
+            raise ImportError('You must have the cjson, json, or simplejson '
                               'module(s) available.')
 
     # Declare json methods
@@ -133,6 +137,7 @@ except ImportError:
 # ------------------------------------------------------------------------------
 # XMLRPClib re-implementations
 
+
 class ProtocolError(Exception):
     """
     JSON-RPC error
@@ -143,6 +148,7 @@ class ProtocolError(Exception):
     """
     pass
 
+
 class AppError(ProtocolError):
     """
     Application error: the error code is not in the pre-defined ones
@@ -247,6 +253,7 @@ class TransportMixIn(object):
         target = JSONTarget()
         return JSONParser(target), target
 
+
 class JSONParser(object):
     def __init__(self, target):
         self.target = target
@@ -257,6 +264,7 @@ class JSONParser(object):
     def close(self):
         pass
 
+
 class JSONTarget(object):
     def __init__(self):
         self.data = []
@@ -280,14 +288,17 @@ class JSONTarget(object):
 
             return data
 
+
 class Transport(TransportMixIn, XMLTransport):
     pass
 
+
 class SafeTransport(TransportMixIn, XMLSafeTransport):
     pass
 
 # ------------------------------------------------------------------------------
 
+
 class ServerProxy(XMLServerProxy):
     """
     Unfortunately, much more of this class has to be copied since
@@ -431,6 +442,7 @@ class ServerProxy(XMLServerProxy):
 
 # ------------------------------------------------------------------------------
 
+
 class _Method(XML_Method):
 
     def __call__(self, *args, **kwargs):
@@ -452,6 +464,7 @@ class _Method(XML_Method):
         # The only thing that changes is the name.
         # return _Method(self.__send, "{0}.{1}".format(self.__name, name))
 
+
 class _Notify(object):
     def __init__(self, request):
         self._request = request
@@ -462,6 +475,7 @@ class _Notify(object):
 # ------------------------------------------------------------------------------
 # Batch implementation
 
+
 class MultiCallMethod(object):
 
     def __init__(self, method, notify=False, config=jsonrpclib.config.DEFAULT):
@@ -492,6 +506,7 @@ class MultiCallMethod(object):
         self.method = new_method
         return self
 
+
 class MultiCallNotify(object):
 
     def __init__(self, multicall, config=jsonrpclib.config.DEFAULT):
@@ -503,6 +518,7 @@ class MultiCallNotify(object):
         self.multicall._job_list.append(new_job)
         return new_job
 
+
 class MultiCallIterator(object):
 
     def __init__(self, results):
@@ -521,6 +537,7 @@ class MultiCallIterator(object):
     def __len__(self):
         return len(self.results)
 
+
 class MultiCall(object):
 
     def __init__(self, server, config=jsonrpclib.config.DEFAULT):
@@ -557,6 +574,7 @@ Server = ServerProxy
 
 # ------------------------------------------------------------------------------
 
+
 class Fault(object):
     """
     JSON-RPC error class
@@ -721,6 +739,7 @@ class Payload(object):
 
 # ------------------------------------------------------------------------------
 
+
 def dump(params=None, methodname=None, rpcid=None, version=None,
          is_response=None, is_notify=None, config=jsonrpclib.config.DEFAULT):
     """
@@ -745,7 +764,7 @@ def dump(params=None, methodname=None, rpcid=None, version=None,
     # Validate method name and parameters
     valid_params = (utils.TupleType, utils.ListType, utils.DictType, Fault)
     if methodname in utils.StringTypes and \
-    not isinstance(params, valid_params):
+            not isinstance(params, valid_params):
         """
         If a method, and params are not in a listish or a Fault,
         error out.
@@ -758,11 +777,12 @@ def dump(params=None, methodname=None, rpcid=None, version=None,
 
     if isinstance(params, Fault):
         # Prepare an error dictionary
+        # pylint: disable=E1103
         return payload.error(params.faultCode, params.faultString)
 
     if type(methodname) not in utils.StringTypes and not is_response:
         # Neither a request nor a response
-        raise ValueError('Method name must be a string, or is_response ' \
+        raise ValueError('Method name must be a string, or is_response '
                          'must be set to True.')
 
     if config.use_jsonclass:
@@ -855,6 +875,7 @@ def loads(data, config=jsonrpclib.config.DEFAULT):
 
 # ------------------------------------------------------------------------------
 
+
 def check_for_errors(result):
     """
     Checks if a result dictionary signals an error
